--===========================================================
-- merge_polys_by_material.ms
-- Contact: martin.ashton@autodesk.com
--
-- Usage: Scripting > Run Script > merge_polys_by_material.ms
--
-- Merges all the objects which share the same material into a 
-- single Editable Poly.
--===========================================================
(	
	-- Attach all the nodes together as one poly.
	function AttachPolys nodes = (
		local result = undefined
		if nodes.count > 1 then (
			undo off
			(
				sourcePoly = convertToPoly nodes[1]
				for i = 2 to nodes.count do (
					polyop.attach sourcePoly nodes[i]
				)
				--result = convertToPoly sourcePoly
				result = sourcePoly
			)
		)
		result
	)
	
	objs = objects as array
	
	materials = for o in objs where o.material != undefined collect o.material
	materials = makeUniqueArray materials
	
	nodes_per_material = for m in materials collect (refs.dependentNodes m)
	for nodes in nodes_per_material do (AttachPolys nodes)
	
	print "The merging is complete."
	ok
)